@@ -116,11 +116,6 @@ CODE_DATA = [
     ['dcall',       'u1', 'mn'],
 
     ['new'  ,    'u2', 'u2', 'c2'],
- 
- #   ['mcall',    'u1'],
- #   ['call_wm',  'u1', 'OBJ'],
- #   ['ncall_wm',  'u1', 'OBJ'],
-
 
     ['mt'  ,     'mn'],
     ['mt__fmt',    'mn', 'OBJ'], 
@@ -174,9 +169,11 @@ CODE_DATA = [
    ['mapnext',  'addr', 'sfp', 'sfp', 'c2'],
    ['smapnext', 'addr', 'sfp', 'sfp', 'OBJ'],
 
-   ['try_begin',   'addr', 'sfp', 'sfp'],
-   ['try_end',     'sfp'],
-   ['catch', 'addr', 'e2', 'sfp'], 
+   ['try', 'addr', 'sfp', 'sfp'],
+   ['try_wc', 'addr', 'sfp'],
+   ['try_end', 'sfp'],
+   ['catch', 'addr', 'OBJ', 'sfp'], 
+   ['throw_again', 'sfp'],
 
    ['throw*', 'ebp'],
    ['throw*', 'sfp'],
@@ -558,9 +555,9 @@ void knh_Compiler_remapAddress(Ctx *ctx, Compiler *o)
 
 	write_chapter(f, '[vmc]')
 
-	CPROTO.append('void knh_KLRCode_utraverse(Ctx *ctx, knh_bytes_t vmc, f_traverse gc)')
+	CPROTO.append('void knh_KLRCode_utraverse(Ctx *ctx, knh_bytes_t vmc, knh_ftraverse gc)')
 	f.write('''
-void knh_KLRCode_utraverse(Ctx *ctx, knh_bytes_t vmc, f_traverse gc)
+void knh_KLRCode_utraverse(Ctx *ctx, knh_bytes_t vmc, knh_ftraverse gc)
 {
 	knhvmc_t *pc = (knhvmc_t*)vmc.buf;
 	knhvmc_t *tail = vmc.buf + vmc.len;
