@@ -101,14 +101,17 @@ knh_type_t knh_Token_totype(Ctx *ctx, Token *o, knh_class_t defc, NameSpace *ns)
 		if(ISB(name, "void")) {
 			return TYPE_void;
 		}
-
-		cid = knh_NameSpace_getClass(ctx, ns, name);
-		if(cid == CLASS_unknown) {
-			cid = defc;
-			knh_Token_perror(ctx, o, KMSG_UCLASSN);
-			knh_Token_perrata(ctx, o, CLASSN(defc));
+		if(knh_Token_isExceptionType(o)) {
+			cid = CLASS_Exception;
+		}
+		else {
+			cid = knh_NameSpace_getClass(ctx, ns, name);
+			if(cid == CLASS_unknown) {
+				cid = defc;
+				knh_Token_perror(ctx, o, KMSG_UCLASSN);
+				knh_Token_perrata(ctx, o, CLASSN(defc));
+			}
 		}
-
 		if(knh_Token_isIteratorType(o)) {
 			cid = knh_pmzclass(ctx, CLASS_Iterator, cid, CLASS_Any);
 		}
@@ -241,23 +244,25 @@ void knh_Token_setLCONST(Ctx *ctx, Token *tk, NameSpace *ns)
 static
 void knh_Token_constCLASS(Ctx *ctx, Token *o, NameSpace *ns)
 {
-	knh_class_t cid = knh_Token_toclass(ctx, o, CLASS_unknown, ns);
-	if(cid == CLASS_unknown) {
-		if(knh_Token_isLCONSTN(o)) {
-			knh_Token_setLCONST(ctx, o, ns);
-		}
-		else {
-			knh_Token_perror(ctx, o, KMSG_UCLASSN);
-			knh_Token_perrata(ctx, o, "null");
-			knh_Token_setCONST(ctx, o, KNH_NULL);
-		}
-		return;
+	if(knh_Token_isExceptionType(o)) {
+		knh_Token_setCONST(ctx, o, UP(knh_tClass[CLASS_Exception].class_cid));
 	}
-	else if(knh_Token_isNotNullType(o)) {
-		//knh_Token_perror(ctx, o, KMSG_IGNNTYPE);
+	else {
+		knh_class_t cid = knh_Token_toclass(ctx, o, CLASS_unknown, ns);
+		if(cid == CLASS_unknown) {
+			if(knh_Token_isLCONSTN(o)) {
+				knh_Token_setLCONST(ctx, o, ns);
+			}
+			else {
+				knh_Token_perror(ctx, o, KMSG_UCLASSN);
+				knh_Token_perrata(ctx, o, "null");
+				knh_Token_setCONST(ctx, o, KNH_NULL);
+			}
+			return;
+		}
+		DEBUG_ASSERT_cid(cid);
+		knh_Token_setCONST(ctx, o, UP(knh_tClass[cid].class_cid));
 	}
-	DEBUG_ASSERT_cid(cid);
-	knh_Token_setCONST(ctx, o, UP(knh_tClass[cid].class_cid));
 }
 
 /* ------------------------------------------------------------------------ */
@@ -294,7 +299,7 @@ void knh_Token_constCMETHODN(Ctx *ctx, Token *o, NameSpace *ns)
 /* [NUM] */
 
 static
-knh_int_t knh_Token_tointeger(Ctx *ctx, Token *o)
+knh_integer_t knh_Token_tointeger(Ctx *ctx, Token *o)
 {
 	knh_bytes_t t = knh_Token_tobytes(o);
 	knh_uinteger_t n = 0, prev = 0, base = 10;
@@ -369,7 +374,7 @@ knh_float_t knh_Token_tofloat(Ctx *ctx, Token *o)
 		if('0' <= t.buf[i] && t.buf[i] <= '9') {
 			prev = v;
 			v = v * 10 + (t.buf[i] - '0');
-#ifdef KNH_USING_MATH
+#if defined(KNH_USING_MATH) && !defined(KONOHA_OS__WINDOWS)
 			if(isinf(v)||isnan(v)) {
 				knh_Token_perror(ctx, o, KMSG_FLOATOVERFLOW);
 				knh_Token_perrata(ctx, o, "0.0");
@@ -390,7 +395,7 @@ knh_float_t knh_Token_tofloat(Ctx *ctx, Token *o)
 		if('0' <= t.buf[i] && t.buf[i] <= '9') {
 			prev = v;
 			c *= 10;
-#ifdef KNH_USING_MATH
+#if defined(KNH_USING_MATH) && !defined(KONOHA_OS__WINDOWS)
 			if(isinf(c)||isnan(c)) {
 				break;
 			}
@@ -577,8 +582,10 @@ void knh_Token_constTSTR(Ctx *ctx, Token *o, knh_class_t reqc, NameSpace *ns)
 		knh_Token_toCONST(o);
 	}
 	else {
-		TODO();
-		knh_Token_toCONST(o);
+		if(DP(o)->tt_next == TT_ADD || DP(o)->tt_next == TT_FMT) {
+			TODO();
+		}
+		knh_Token_setCONST(ctx, o, new_Object_parseOf(ctx, (String*)DP(o)->data));
 	}
 }
 
@@ -641,32 +648,24 @@ void knh_Token_constCONSTN(Ctx *ctx, Token *o, NameSpace *ns)
 	if(loc == -1) {
 		if(knh_NameSpace_existsLocalConst(ctx, ns, t)) {
 			knh_Token_setCONST(ctx, o, knh_NameSpace_getLocalConst(ctx, ns, t));
+			return ;
 		}
-		else {
-			knh_Token_perror(ctx, o, KMSG_UCONSTN);
-			knh_Token_perrata(ctx, o, "null");
-			knh_Token_setCONST(ctx, o, KNH_NULL);
-		}
-		return;
-	}
-	knh_class_t cid = knh_NameSpace_getClass(ctx, ns, knh_bytes_first(t, loc));
-	if(cid == CLASS_unknown) {
-		knh_Token_perror(ctx, o, KMSG_UCONSTN);
-		knh_Token_perrata(ctx, o, "null");
-		knh_Token_setCONST(ctx, o, KNH_NULL);
 	}
 	else {
-		char buf[CLASSNAME_BUFSIZ*2];
-		knh_snprintf(buf, sizeof(buf), "%s.%s", CLASSN(cid), &t.buf[loc+1]);
-		t = B(buf);
-		if(knh_tConst_exists(ctx, t)) {
-			knh_Token_setCONST(ctx, o, knh_tConst_value(ctx, t));
-		}else{
-			knh_Token_perror(ctx, o, KMSG_UCONSTN);
-			knh_Token_perrata(ctx, o, "null");
-			knh_Token_setCONST(ctx, o, KNH_NULL);
+		knh_class_t cid = knh_NameSpace_getClass(ctx, ns, knh_bytes_first(t, loc));
+		if(cid != CLASS_unknown) {
+			char buf[CLASSNAME_BUFSIZ*2];
+			knh_snprintf(buf, sizeof(buf), "%s.%s", CLASSN(cid), &t.buf[loc+1]);
+			t = B(buf);
+			if(knh_tConst_exists(ctx, t)) {
+				knh_Token_setCONST(ctx, o, knh_tConst_value(ctx, t));
+				return;
+			}
 		}
 	}
+	knh_Token_perror(ctx, o, KMSG_UCONSTN);
+	knh_Token_perrata(ctx, o, "null");
+	knh_Token_setCONST(ctx, o, KNH_NULL);
 }
 
 /* ------------------------------------------------------------------------ */
