@@ -42,7 +42,7 @@ extern "C" {
 /* ../class/konoha/knh_AffineConv.c */
 void knh_AffineConv_struct_init(Ctx *ctx, knh_AffineConv_struct *b, int init, Object *cs);
 AffineConv *new_AffineConv(Ctx *ctx, knh_float_t fa, knh_float_t fb);
-f_mapper knh_tmapper_faffine(knh_class_t scid, knh_class_t tcid);
+knh_fmapper knh_tmapper_faffine(knh_class_t scid, knh_class_t tcid);
 /* ../class/konoha/knh_Array.c */
 knh_Array_t* new_Array0(Ctx *ctx, size_t capacity);
 knh_Array_t* new_Array(Ctx *ctx, knh_class_t p1, size_t capacity);
@@ -92,7 +92,7 @@ Mapper *knh_tMapper_newArrayIterator(Ctx *ctx, knh_class_t acid, knh_class_t ici
 /* ../class/konoha/knh_array_t.c */
 size_t knh_barray_capacity(void *a);
 knh_uchar_t *knh_barray_malloc(Ctx *ctx, size_t capacity);
-void knh_barray_free(knh_uchar_t *a);
+void knh_barray_free(Ctx *ctx, knh_uchar_t *a);
 knh_uchar_t *knh_barray_resize(Ctx *ctx, knh_uchar_t *a, size_t newsize);
 size_t knh_oarray_capacity(void *a);
 size_t knh_oarray_opsize(void *a);
@@ -105,7 +105,7 @@ Object** knh_oarray_malloc(Ctx *ctx, size_t capacity, Object *value);
 Object **knh_oarray_resize(Ctx *ctx, Object **a, size_t newsize);
 Object** knh_oarray_grow(Ctx *ctx, Object **a);
 Object **knh_oarray_copy(Ctx *ctx, Object **a, size_t s, size_t offset);
-void knh_oarray_traverse(Ctx *ctx, Object **a, f_traverse ftr);
+void knh_oarray_traverse(Ctx *ctx, Object **a, knh_ftraverse ftr);
 void knh_oarray_free(Ctx *ctx, knh_Object_t **a);
 /* ../class/konoha/knh_Boolean.c */
 Object *knh_Boolean_fdefault(Ctx *ctx, knh_class_t cid);
@@ -132,8 +132,6 @@ String* knh_Bytes_String(Ctx *ctx, Bytes *o, Mapper *mpr);
 Bytes* knh_String_Bytes(Ctx *ctx, String *s, Mapper *map);
 /* ../class/konoha/knh_Bytes_byte_t.c */
 size_t knh_size(size_t s);
-knh_bytes_t new_bytes(char *c);
-knh_bytes_t new_bytes__2(char *buf, size_t len);
 knh_int_t knh_bytes_strcmp(knh_bytes_t v1, knh_bytes_t v2);
 knh_int_t knh_bytes_strcasecmp(knh_bytes_t v1, knh_bytes_t v2);
 knh_bool_t knh_bytes_equals(knh_bytes_t v1, knh_bytes_t v2);
@@ -154,7 +152,7 @@ knh_float_t knh_bytes_tofloat(knh_bytes_t t);
 knh_int64_t knh_bytes_toint64(knh_bytes_t t);
 /* ../class/konoha/knh_BytesConv.c */
 void knh_BytesConv_struct_init(Ctx *ctx, knh_BytesConv_struct *b, int init, Object *cs);
-void knh_BytesConv_struct_traverse(Ctx *ctx, knh_BytesConv_struct *b, f_traverse ftr);
+void knh_BytesConv_struct_traverse(Ctx *ctx, knh_BytesConv_struct *b, knh_ftraverse ftr);
 size_t knh_BytesConv_conv(Ctx *ctx, BytesConv *o, knh_bytes_t t, knh_Bytes_t *ba);
 BytesConv* new_BytesConv(Ctx *ctx, String *name, f_bconv fbconv);
 BytesConv* new_BytesConv__iconv(Ctx *ctx, char *from, char *to);
@@ -184,7 +182,7 @@ char *TYPEQ(knh_type_t type);
 char *knh_TYPEN(Ctx *ctx, knh_type_t type);
 /* ../class/konoha/knh_ClassMap.c */
 void knh_ClassMap_struct_init(Ctx *ctx, knh_ClassMap_struct *b, int init, Object *cs);
-void knh_ClassMap_struct_traverse(Ctx *ctx, knh_ClassMap_struct *b, f_traverse gc);
+void knh_ClassMap_struct_traverse(Ctx *ctx, knh_ClassMap_struct *b, knh_ftraverse gc);
 ClassMap* new_ClassMap0(Ctx *ctx, knh_ushort_t capacity);
 void knh_ClassMap_resize(Ctx *ctx, ClassMap *o, size_t newsize);
 int knh_ClassMap_util_cmp(const Mapper *m1, const Mapper *m2);
@@ -193,7 +191,7 @@ void knh_ClassMap_add(Ctx *ctx, ClassMap *o, Mapper *map);
 void knh_ClassMap__dump(Ctx *ctx, ClassMap *o, OutputStream *w, String *m);
 /* ../class/konoha/knh_ClassStruct.c */
 void knh_ClassStruct_struct_init(Ctx *ctx, knh_ClassStruct_struct *b, int init, Object *cs);
-void knh_ClassStruct_struct_traverse(Ctx *ctx, knh_ClassStruct_struct *b, f_traverse gc);
+void knh_ClassStruct_struct_traverse(Ctx *ctx, knh_ClassStruct_struct *b, knh_ftraverse gc);
 ClassStruct* new_ClassStruct0(Ctx *ctx, knh_struct_t sid, int method_size);
 void knh_ClassStruct_finit(Ctx *ctx, ClassStruct *o, knh_class_t self_cid, Object **v);
 knh_index_t knh_Class_indexOfField(knh_class_t cid, knh_fieldn_t fn);
@@ -205,7 +203,7 @@ Method* knh_Class_getMethod__(Ctx *ctx, knh_class_t this_cid, knh_methodn_t mn,
 void knh_cfield_dump(Ctx *ctx, knh_cfield_t *f, size_t offset, size_t fsize, OutputStream *w);
 /* ../class/konoha/knh_Connection.c */
 void knh_Connection_struct_init(Ctx *ctx, knh_Connection_struct *b, int init, Object *cs);
-void knh_Connection_struct_traverse(Ctx *ctx, knh_Connection_struct *b, f_traverse ftr);
+void knh_Connection_struct_traverse(Ctx *ctx, knh_Connection_struct *b, knh_ftraverse ftr);
 void knh_Connection_open(Ctx *ctx, Connection *o, String *urn);
 Connection* new_Connection(Ctx *ctx, String *urn);
 void knh_Connection_close(Ctx *ctx, Connection *o);
@@ -241,7 +239,7 @@ void *knh_Context_mallocOnce(Ctx* ctx, size_t n);
 void knh_Context_freeOnce(Ctx* ctx, void *p);
 /* ../class/konoha/knh_DictIdx.c */
 void knh_DictIdx_struct_init(Ctx *ctx, knh_DictIdx_struct *b, int init, Object *cs);
-void knh_DictIdx_struct_traverse(Ctx *ctx, knh_DictIdx_struct *b, f_traverse gc);
+void knh_DictIdx_struct_traverse(Ctx *ctx, knh_DictIdx_struct *b, knh_ftraverse gc);
 DictIdx* new_DictIdx(Ctx *ctx, size_t initialCapacity, knh_int_t offset);
 size_t knh_DictIdx_size(DictIdx *o);
 knh_index_t knh_DictIdx_index(Ctx *ctx, DictIdx *o, knh_bytes_t v);
@@ -273,7 +271,7 @@ METHOD knh__DictMap_opItr(Ctx *ctx, knh_sfp_t *sfp);
 void knh_DictMap__k(Ctx *ctx, DictMap *o, OutputStream *w, String *m);
 /* ../class/konoha/knh_DictMapSet.c */
 knh_dict_t* knh_dict_resize(Ctx *ctx, knh_dict_t *a, size_t newsize);
-void knh_dict_traverse(Ctx *ctx, knh_dict_t *a, f_traverse ftr);
+void knh_dict_traverse(Ctx *ctx, knh_dict_t *a, knh_ftraverse ftr);
 void knh_DictMap_sort(DictMap *o);
 void knh_DictSet_sort(DictSet *o);
 knh_dict_t *knh_dictmap_malloc(Ctx *ctx, size_t init);
@@ -327,7 +325,7 @@ void knh_DictSet__k(Ctx *ctx, DictSet *o, OutputStream *w, String *m);
 void knh_DictSet__dump(Ctx *ctx, DictSet *o, OutputStream *w, String *m);
 /* ../class/konoha/knh_Exception.c */
 void knh_Exception_struct_init(Ctx *ctx, knh_Exception_struct *b, int init, Object *cs);
-void knh_Exception_struct_traverse(Ctx *ctx, knh_Exception_struct *b, f_traverse gc);
+void knh_Exception_struct_traverse(Ctx *ctx, knh_Exception_struct *b, knh_ftraverse gc);
 Exception* knh_Exception_new__init(Ctx *ctx, Exception *o, String *e, String *msg, Object *bag);
 Exception* new_Exception__Nue(Ctx *ctx, knh_Nue_t *nue);
 /* ../class/konoha/knh_Exception_api1.c */
@@ -339,7 +337,7 @@ void knh_Exception__k(Ctx *ctx, Exception *o, OutputStream *w, String *m);
 void knh_Exception__dump(Ctx *ctx, Exception *o, OutputStream *w, String *m);
 /* ../class/konoha/knh_ExceptionHandler.c */
 void knh_ExceptionHandler_struct_init(Ctx *ctx, knh_ExceptionHandler_struct *b, int init, Object *cs);
-void knh_ExceptionHandler_struct_traverse(Ctx *ctx, knh_ExceptionHandler_struct *b, f_traverse gc);
+void knh_ExceptionHandler_struct_traverse(Ctx *ctx, knh_ExceptionHandler_struct *b, knh_ftraverse gc);
 ExceptionHandler* new_ExceptionHandler(Ctx *ctx);
 Object *knh_ExceptionHandler_fdefault(Ctx *ctx, knh_class_t cid);
 void knh_ExceptionHandler_longjmp(Ctx *ctx, ExceptionHandler *o, Exception *e);
@@ -382,7 +380,7 @@ void knh_Float__bits(Ctx *ctx, Float *o, OutputStream *w, String *m);
 void knh_Float__dump(Ctx *ctx, Float *o, OutputStream *w, String *m);
 /* ../class/konoha/knh_FloatUnit.c */
 void knh_FloatUnit_struct_init(Ctx *ctx, knh_FloatUnit_struct *b, int init, Object *cs);
-void knh_FloatUnit_struct_traverse(Ctx *ctx, knh_FloatUnit_struct *b, f_traverse gc);
+void knh_FloatUnit_struct_traverse(Ctx *ctx, knh_FloatUnit_struct *b, knh_ftraverse gc);
 FloatUnit *new_FloatUnit(Ctx *ctx, knh_flag_t flag, knh_class_t cid, String *tag, knh_float_t min, knh_float_t max, knh_float_t defvalue, knh_float_t step);
 void knh_FloatUnit_initStep(Ctx *ctx, FloatUnit *b, knh_float_t step);
 void knh_FloatUnit_initMinMax(Ctx *ctx, FloatUnit *b, knh_float_t min, knh_float_t max);
@@ -392,7 +390,7 @@ void knh_HashMap_struct_init(Ctx *ctx, knh_HashMap_struct *b, int init, Object *
 knh_hashmapentry_t *new_hashmapentry(Ctx *ctx, HashMap *o);
 size_t knh_hashmapentry_capacity(Ctx *ctx, HashMap *o);
 knh_hashmapentry_t *knh_hashmapentry_at(HashMap *o, size_t n);
-void knh_HashMap_struct_traverse(Ctx *ctx, knh_HashMap_struct *b, f_traverse ftr);
+void knh_HashMap_struct_traverse(Ctx *ctx, knh_HashMap_struct *b, knh_ftraverse ftr);
 HashMap* new_HashMap(Ctx *ctx, char *name, size_t capacity);
 Object *knh_HashMap_get__hcode(Ctx *ctx, HashMap *o, knh_hcode_t hcode);
 void knh_HashMap_set__hcode(Ctx *ctx, HashMap *o, knh_hcode_t hcode, Any *value);
@@ -410,7 +408,7 @@ Iterator* knh_HashMap_Iterator(Ctx *ctx, HashMap *o, Mapper *mpr);
 METHOD knh__HashMap_opItr(Ctx *ctx, knh_sfp_t *sfp);
 /* ../class/konoha/knh_HashSet.c */
 void knh_HashSet_struct_init(Ctx *ctx, knh_HashSet_struct *b, int init, Object *cs);
-void knh_HashSet_struct_traverse(Ctx *ctx, knh_HashSet_struct *b, f_traverse ftr);
+void knh_HashSet_struct_traverse(Ctx *ctx, knh_HashSet_struct *b, knh_ftraverse ftr);
 HashSet* new_HashSet(Ctx *ctx, char *name, size_t capacity);
 knh_uint_t knh_HashSet_get__hcode(Ctx *ctx, HashSet *o, knh_hcode_t hcode);
 void knh_HashSet_set__hcode(Ctx *ctx, HashSet *o, knh_hcode_t hcode, knh_uint_t value);
@@ -419,7 +417,7 @@ void knh_HashSet_remove__hcode(Ctx *ctx, HashSet *o, knh_hcode_t hcode);
 void knh_HashSet_clear(Ctx *ctx, HashSet *o);
 /* ../class/konoha/knh_InputStream.c */
 void knh_InputStream_struct_init(Ctx *ctx, knh_InputStream_struct *b, int init, Object *cs);
-void knh_InputStream_struct_traverse(Ctx *ctx, knh_InputStream_struct *b, f_traverse ftr);
+void knh_InputStream_struct_traverse(Ctx *ctx, knh_InputStream_struct *b, knh_ftraverse ftr);
 Object *knh_InputStream_open(Ctx *ctx, InputStream *o, String *urn);
 int knh_InputStream_getc(Ctx *ctx, InputStream *o);
 size_t knh_InputStream_read(Ctx *ctx, InputStream *o, char *buf, size_t bufsiz);
@@ -483,7 +481,7 @@ void knh_write_bits(Ctx *ctx, OutputStream *w, knh_uint64_t n, size_t bits);
 void knh_Int__bits(Ctx *ctx, Int *o, OutputStream *w, String *m);
 /* ../class/konoha/knh_IntUnit.c */
 void knh_IntUnit_struct_init(Ctx *ctx, knh_IntUnit_struct *b, int init, Object *cs);
-void knh_IntUnit_struct_traverse(Ctx *ctx, knh_IntUnit_struct *b, f_traverse gc);
+void knh_IntUnit_struct_traverse(Ctx *ctx, knh_IntUnit_struct *b, knh_ftraverse gc);
 IntUnit *new_IntUnit(Ctx *ctx, knh_flag_t flag, knh_class_t cid, String *urn, String *tag, knh_integer_t min, knh_integer_t max, knh_integer_t defvalue, knh_int_t bf_start, knh_int_t bf_end);
 void knh_IntUnit_initId(Ctx *ctx, IntUnit *b, knh_flag_t flag, knh_class_t cid, String *urn, String *tag);
 void knh_IntUnit_initMinMax(Ctx *ctx, IntUnit *b, knh_integer_t min, knh_integer_t max);
@@ -492,31 +490,31 @@ void knh_IntUnit_initDefaultValue(Ctx *ctx, IntUnit *b, knh_integer_t v);
 /* ../class/konoha/knh_Iterator.c */
 void knh_Iterator_struct_init(Ctx *ctx, knh_Iterator_struct *b, int init, Object *cs);
 void knh_Iterator_struct_copy(Ctx *ctx, knh_Iterator_struct *b, knh_Iterator_struct *b2);
-void knh_Iterator_struct_traverse(Ctx *ctx, knh_Iterator_struct *b, f_traverse gc);
+void knh_Iterator_struct_traverse(Ctx *ctx, knh_Iterator_struct *b, knh_ftraverse gc);
 Iterator* new_Iterator(Ctx *ctx, knh_class_t p1, Any *source, f_next fnext);
 Object *knh_Iterator_slice(Ctx *ctx, Iterator *o);
 /* ../class/konoha/knh_Iterator_api1.c */
 void knh_Iterator__dump(Ctx *ctx, Iterator *o, OutputStream *w, String *m);
 /* ../class/konoha/knh_LRUHashMap.c */
 void knh_LRUHashMap_struct_init(Ctx *ctx, knh_LRUHashMap_struct *b, int init, Object *cs);
-void knh_LRUHashMap_struct_traverse(Ctx *ctx, knh_LRUHashMap_struct *b, f_traverse ftr);
+void knh_LRUHashMap_struct_traverse(Ctx *ctx, knh_LRUHashMap_struct *b, knh_ftraverse ftr);
 LRUHashMap* new_LRUHashMap(Ctx *ctx, char *name, size_t capacity);
 Object *knh_LRUHashMap_get__hcode(Ctx *ctx, LRUHashMap *o, knh_hcode_t hcode);
 void knh_LRUHashMap_set__hcode(Ctx *ctx, LRUHashMap *o, knh_hcode_t hcode, Any *value);
 void knh_LRUHashMap_clear(Ctx *ctx, LRUHashMap *o);
 /* ../class/konoha/knh_Mapper.c */
 void knh_Mapper_struct_init(Ctx *ctx, knh_Mapper_struct *b, int init, Object *cs);
-void knh_Mapper_struct_traverse(Ctx *ctx, knh_Mapper_struct *b, f_traverse ftr);
-Mapper* new_Mapper(Ctx *ctx, knh_flag_t flag, knh_class_t scid, knh_class_t tcid, f_mapper fmap, Object *mapdata);
+void knh_Mapper_struct_traverse(Ctx *ctx, knh_Mapper_struct *b, knh_ftraverse ftr);
+Mapper* new_Mapper(Ctx *ctx, knh_flag_t flag, knh_class_t scid, knh_class_t tcid, knh_fmapper fmap, Object *mapdata);
 Mapper* new_MapMap(Ctx *ctx, Mapper *m1, Mapper *m2);
 Object *knh_Mapper_execMap(Ctx *ctx, Mapper *o, Object *sub);
 void knh_Mapper__k(Ctx *ctx, Mapper *o, OutputStream *w, String *m);
 /* ../class/konoha/knh_Method.c */
 void knh_Method_struct_init(Ctx *ctx, knh_Method_struct *b, int init, Object *cs);
 void knh_Method_struct_copy(Ctx *ctx, knh_Method_struct *b, knh_Method_struct *b2);
-void knh_Method_struct_traverse(Ctx *ctx, knh_Method_struct *b, f_traverse gc);
+void knh_Method_struct_traverse(Ctx *ctx, knh_Method_struct *b, knh_ftraverse gc);
 knh_bool_t knh_Method_isAbstract(Method *o);
-Method* new_Method(Ctx *ctx, knh_flag_t flag, knh_class_t cid, knh_methodn_t mn, f_method func);
+Method* new_Method(Ctx *ctx, knh_flag_t flag, knh_class_t cid, knh_methodn_t mn, knh_fmethod func);
 knh_hcode_t knh_Method_hashCode(Method *o);
 int knh_Method_compareTo(Method *o, Method *o2);
 void knh_Method_toAbstract(Ctx *ctx, Method *o);
@@ -535,7 +533,7 @@ void knh_Method__dump(Ctx *ctx, Method *o, OutputStream *w, String *m);
 /* ../class/konoha/knh_MethodField.c */
 void knh_MethodField_struct_init(Ctx *ctx, knh_MethodField_struct *b, int init, Object *cs);
 void knh_MethodField_struct_copy(Ctx *ctx, knh_MethodField_struct *b, knh_MethodField_struct *b2);
-void knh_MethodField_struct_traverse(Ctx *ctx, knh_MethodField_struct *b, f_traverse gc);
+void knh_MethodField_struct_traverse(Ctx *ctx, knh_MethodField_struct *b, knh_ftraverse gc);
 MethodField* new_MethodField(Ctx *ctx, knh_flag_t flag, size_t size);
 MethodField *new_MethodField__0(Ctx *ctx, knh_flag_t flag, knh_type_t rtype);
 MethodField *new_MethodField__1(Ctx *ctx, knh_flag_t flag, knh_type_t rtype, knh_type_t t1, knh_fieldn_t fn1);
@@ -553,7 +551,7 @@ knh_mfield_t knh_MethodField_pfields(MethodField *o, size_t n);
 knh_mfield_t knh_MethodField_lastfield(MethodField *o);
 /* ../class/konoha/knh_NameSpace.c */
 void knh_NameSpace_struct_init(Ctx *ctx, knh_NameSpace_struct *b, int init, Object *cs);
-void knh_NameSpace_struct_traverse(Ctx *ctx, knh_NameSpace_struct *b, f_traverse ftr);
+void knh_NameSpace_struct_traverse(Ctx *ctx, knh_NameSpace_struct *b, knh_ftraverse ftr);
 NameSpace* new_NameSpace(Ctx *ctx, NameSpace *parent, String *nsname);
 void knh_NameSpace_setClass(Ctx *ctx, NameSpace *o, String *name, knh_class_t c);
 knh_class_t knh_NameSpace_getClass(Ctx *ctx, NameSpace *o, knh_bytes_t name);
@@ -629,7 +627,7 @@ void knh_Object__refc(Ctx *ctx, Object *o, OutputStream *w, String *m);
 void knh_Object__addr(Ctx *ctx, Object *b, OutputStream *w, String *m);
 /* ../class/konoha/knh_OutputStream.c */
 void knh_OutputStream_struct_init(Ctx *ctx, knh_OutputStream_struct *b, int init, Object *cs);
-void knh_OutputStream_struct_traverse(Ctx *ctx, knh_OutputStream_struct *b, f_traverse gc);
+void knh_OutputStream_struct_traverse(Ctx *ctx, knh_OutputStream_struct *b, knh_ftraverse gc);
 Object *knh_OutputStream_open(Ctx *ctx, OutputStream *o, String *urn, String *mode);
 void knh_OutputStream_putc(Ctx *ctx, OutputStream *o, int ch);
 void knh_OutputStream_write(Ctx *ctx, OutputStream *o, knh_bytes_t buf);
@@ -663,6 +661,7 @@ void knh_write__class(Ctx *ctx, OutputStream *w, knh_class_t cid);
 void knh_write__expt(Ctx *ctx, OutputStream *w, knh_expt_t cid);
 void knh_write__mn(Ctx *ctx, OutputStream *w, knh_methodn_t mn);
 String* knh_Object_movableText(Ctx *ctx, Object *b, knh_methodn_t mn, Any *m);
+void konoha_setverbose(int v);
 METHOD knh_fmethod_movableText(Ctx *ctx, knh_sfp_t *sfp);
 /* ../class/konoha/knh_Range.c */
 Range *new_Range(Ctx *ctx, Object *start, Object *end);
@@ -672,7 +671,7 @@ METHOD knh__Range_new__slice(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Range_new__offset(Ctx *ctx, knh_sfp_t *sfp);
 /* ../class/konoha/knh_Regex.c */
 Regex *new_Regex(Ctx *ctx, String *pattern);
-void knh_Regex_traverse(Ctx *ctx, Regex *o, f_traverse ftr);
+void knh_Regex_traverse(Ctx *ctx, Regex *o, knh_ftraverse ftr);
 int knh_String_opMatch(Ctx *ctx, String *o, Regex *re);
 METHOD knh__String_opMatch(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Regex_opMatch(Ctx *ctx, knh_sfp_t *sfp);
@@ -680,7 +679,7 @@ Array *knh_Regex_split(Ctx *ctx, Regex *o, String *s);
 void knh_Regex__s(Ctx *ctx, Regex *o, OutputStream *w, String *m);
 /* ../class/konoha/knh_ResultSet.c */
 void knh_ResultSet_struct_init(Ctx *ctx, knh_ResultSet_struct *b, int init, Object *cs);
-void knh_ResultSet_struct_traverse(Ctx *ctx, knh_ResultSet_struct *b, f_traverse ftr);
+void knh_ResultSet_struct_traverse(Ctx *ctx, knh_ResultSet_struct *b, knh_ftraverse ftr);
 knh_boolean_t knh_ResultSet_next(Ctx *ctx, ResultSet *o);
 void knh_ResultSet_initTargetClass(ResultSet *o, knh_class_t tcid);
 knh_index_t knh_ResultSet_index(Ctx *ctx, ResultSet *o, knh_bytes_t name);
@@ -692,7 +691,7 @@ void knh_ResultSet__dump(Ctx *ctx, ResultSet *o, OutputStream *w, String *m);
 /* ../class/konoha/knh_Runtime.c */
 int knh_Runtime_isAllClosed(void);
 void knh_Runtime_struct_init(Ctx *ctx, knh_Runtime_struct *b, int init, Object *cs);
-void knh_Runtime_struct_traverse(Ctx *ctx, knh_Runtime_struct *b, f_traverse gc);
+void knh_Runtime_struct_traverse(Ctx *ctx, knh_Runtime_struct *b, knh_ftraverse gc);
 void knh_Runtime_lock(Ctx *ctx, Runtime *o);
 void knh_Runtime_unlock(Ctx *ctx, Runtime *o);
 Runtime* new_Runtime0(knh_uint_t runtime_id);
@@ -753,7 +752,7 @@ knh_type_t	knh_ObjectParser_typing(Ctx *ctx, knh_bytes_t t);
 Object *new_Object_parseOf(Ctx *ctx, String *s);
 /* ../class/konoha/knh_StringUnit.c */
 void knh_StringUnit_struct_init(Ctx *ctx, knh_StringUnit_struct *b, int init, Object *cs);
-void knh_StringUnit_struct_traverse(Ctx *ctx, knh_StringUnit_struct *b, f_traverse gc);
+void knh_StringUnit_struct_traverse(Ctx *ctx, knh_StringUnit_struct *b, knh_ftraverse gc);
 StringUnit *new_StringUnit(Ctx *ctx, knh_flag_t flag, knh_class_t cid, String *tag);
 Object *knh_String_cspec(Ctx *ctx);
 /* ../class/konoha/knh_System.c */
@@ -780,7 +779,7 @@ Object *knh_Tuple2_get__fast(Tuple2 *b, knh_int_t index);
 void knh_Tuple2__dump(Ctx *ctx, Tuple2 *b, OutputStream *w, String *m);
 /* ../class/konohac/knh_Compiler.c */
 void knh_Compiler_struct_init(Ctx *ctx, knh_Compiler_struct *b, int init, Object *cs);
-void knh_Compiler_struct_traverse(Ctx *ctx, knh_Compiler_struct *b, f_traverse ftr);
+void knh_Compiler_struct_traverse(Ctx *ctx, knh_Compiler_struct *b, knh_ftraverse ftr);
 Compiler* knh_Context_getCompiler(Ctx *ctx);
 NameSpace *knh_Context_getNameSpace(Ctx *ctx);
 NameSpace *knh_Context_setNameSpace(Ctx *ctx, String *nsname);
@@ -800,7 +799,7 @@ void *knh_Compiler_asmmalloc(Ctx *ctx, Compiler *cpr, size_t size);
 /* ../class/konohac/knh_KLRCode.c */
 void knh_KLRCode_struct_init(Ctx *ctx, knh_KLRCode_struct *b, int init, Object *cs);
 void knh_KLRCode_struct_copy(Ctx *ctx, knh_KLRCode_struct *b, knh_KLRCode_struct *b2);
-void knh_KLRCode_struct_traverse(Ctx *ctx, knh_KLRCode_struct *b, f_traverse gc);
+void knh_KLRCode_struct_traverse(Ctx *ctx, knh_KLRCode_struct *b, knh_ftraverse gc);
 KLRCode* new_KLRCode(Ctx *ctx, knh_fileid_t fileid, knh_bytes_t elf, knh_bytes_t dwarf);
 void knh_Method_setKLRCode(Ctx *ctx, Method *mtd, KLRCode *code);
 knh_bytes_t knh_KLRCode_tobytes(KLRCode *o);
@@ -872,7 +871,7 @@ void knh_Compiler_perror(Ctx *ctx, Compiler *cpr, int pe, char *msg);
 void knh_Compiler_assert(Ctx *ctx, Compiler *cpr, int c);
 /* ../class/konohac/knh_Stmt.c */
 void knh_Stmt_struct_init(Ctx *ctx, knh_Stmt_struct *b, int init, Object *cs);
-void knh_Stmt_struct_traverse(Ctx *ctx, knh_Stmt_struct *b, f_traverse gc);
+void knh_Stmt_struct_traverse(Ctx *ctx, knh_Stmt_struct *b, knh_ftraverse gc);
 Stmt* new_Stmt(Ctx *ctx, knh_flag_t flag, knh_stmt_t stt);
 Stmt* new_StmtDONE(Ctx *ctx);
 void knh_Stmt_done(Ctx *ctx, Stmt *o);
@@ -998,7 +997,7 @@ int knh_Term_isERR(Term *tm);
 void knh_Token_setERR(Ctx *ctx, Token *tk, String *msg);
 /* ../class/konohac/knh_Token.c */
 void knh_Token_struct_init(Ctx *ctx, knh_Token_struct *b, int init, Object *cs);
-void knh_Token_struct_traverse(Ctx *ctx, knh_Token_struct *b, f_traverse gc);
+void knh_Token_struct_traverse(Ctx *ctx, knh_Token_struct *b, knh_ftraverse gc);
 Token* new_Token(Ctx *ctx, knh_flag_t flag, knh_fileid_t fileid, knh_line_t line, knh_token_t tt);
 Token *new_Token__text(Ctx *ctx, Any *fln, knh_bytes_t text);
 void knh_Token_setFL(Token *o, Any *fln);
@@ -1079,12 +1078,15 @@ int ALT_dlclose(void* handle);
 int main(int argc, char **argv);
 /* ../konoha/runtime/knh_tClass.c */
 void knh_tClass_init0(void);
-void knh_tClass_traverse(Ctx *ctx, f_traverse f);
+void knh_tClass_traverse(Ctx *ctx, knh_ftraverse f);
 knh_class_t knh_tClass_newId(Ctx *ctx);
 size_t knh_tClass_size(void);
 int IS_cid(knh_class_t cid);
 void KNH_TCLASS_NAME(Ctx *ctx, knh_class_t cid, String *lname);
 String *knh_tClass_name(knh_class_t cid);
+ClassMap *KNH_CLASSMAP_DEFAULT(Ctx *ctx);
+knh_boolean_t knh_ClassMap_isDefault(ClassMap *o);
+void knh_tClass_readyClassMap(Ctx *ctx, knh_class_t cid);
 Object *knh_tClass_defaultValue(Ctx *ctx, knh_class_t cid);
 knh_class_t KNH_TCLASS__T(Ctx *ctx, knh_flag_t flag, char *text, knh_class_t cid, knh_struct_t sid, knh_class_t supcid, knh_Object_t *cspec, f_default fdefault, int method_size);
 void KNH_TCLASS_DEFAULT(Ctx *ctx, knh_class_t cid, Object *value, f_default fdefault);
@@ -1097,18 +1099,19 @@ knh_class_t knh_tClass_findcid(Ctx *ctx, knh_bytes_t lname);
 /* ../konoha/runtime/knh_tConst.c */
 knh_bool_t knh_tConst_exists(Ctx *ctx, knh_bytes_t name);
 Object *knh_tConst_value(Ctx *ctx, knh_bytes_t name);
-knh_bool_t knh_tClass_addClassConst(Ctx *ctx, knh_class_t cid, knh_bytes_t name, Object *value);
+knh_bool_t knh_tConst_addClassConst(Ctx *ctx, knh_class_t cid, knh_bytes_t name, Object *value);
 void KNH_TCONST(Ctx *ctx, String *name, Object *value);
 void KNH_TCONST__T(Ctx *ctx, char *name, Object *value);
+knh_bool_t knh_tConst_addGlobalConst(Ctx *ctx, String *name, Object *value);
 Object *knh_tConst_systemValue(Ctx *ctx, int n);
 /* ../konoha/runtime/knh_tContext.c */
 void knh_tContext_init0(void);
 knh_Context_t *new_Context0(Runtime *runtime, size_t stacksize);
-void knh_Context_traverse(Ctx *ctx, knh_Context_t *o, f_traverse ftr);
-void knh_tContext_traverse(Ctx* ctx, f_traverse f);
+void knh_Context_traverse(Ctx *ctx, knh_Context_t *o, knh_ftraverse ftr);
+void knh_tContext_traverse(Ctx* ctx, knh_ftraverse f);
 /* ../konoha/runtime/knh_tExpt.c */
 void knh_tExpt_init0(void);
-void knh_tExpt_traverse(Ctx *ctx, f_traverse ftr);
+void knh_tExpt_traverse(Ctx *ctx, knh_ftraverse ftr);
 knh_class_t knh_tExpt_newId(Ctx *ctx);
 int IS_eid(knh_expt_t eid);
 knh_flag_t knh_tExpt_flag(knh_expt_t eid);
@@ -1118,13 +1121,13 @@ String *knh_tExpt_name(knh_expt_t eid);
 knh_expt_t knh_texpt_forname(Ctx *ctx, knh_bytes_t msg, knh_expt_t def);
 knh_expt_t KNH_TEXPT(Ctx *ctx, knh_flag_t flag, knh_class_t eid, String *name, char *pname);
 /* ../konoha/runtime/knh_tMapper.c */
-void KNH_TMAPPER(Ctx *ctx, knh_flag_t flag, knh_type_t stype, knh_type_t ttype, f_mapper fmap, Object *mapdata);
+void KNH_TMAPPER(Ctx *ctx, knh_flag_t flag, knh_type_t stype, knh_type_t ttype, knh_fmapper fmap, Object *mapdata);
 Object* knh_Mapper_fInterface(Ctx *ctx, Object *o, Mapper *mpr);
 Object* knh_Mapper_fNull(Ctx *ctx, Object *o, Mapper *mpr);
 knh_bool_t knh_Mapper_isNoSuchMapping(Mapper *o);
 Mapper *knh_tMapper_find(Ctx *ctx, knh_class_t scid, knh_class_t tcid);
 /* ../konoha/runtime/knh_tMethod.c */
-void KNH_TMETHOD(Ctx *ctx, knh_flag_t tflag, f_method func, void *optfunc, knh_ushort_t delta, knh_class_t cid, knh_methodn_t mn, MethodField *mf);
+void KNH_TMETHOD(Ctx *ctx, knh_flag_t tflag, knh_fmethod func, void *optfunc, knh_ushort_t delta, knh_class_t cid, knh_methodn_t mn, MethodField *mf);
 Method *knh_Method_ufind(Ctx *ctx, knh_class_t cid, knh_methodn_t mn);
 Method *knh_tMethod_findMT(Ctx *ctx, knh_class_t cid, knh_methodn_t mn);
 /* ../konoha/runtime/knh_tName.c */
@@ -1143,25 +1146,28 @@ knh_fileid_t knh_tName_getFileId(Ctx *ctx, knh_bytes_t t);
 String *knh_tfileid_name(knh_fileid_t fileid);
 /* ../konoha/runtime/knh_tObject.c */
 void *knh_malloc(Ctx *ctx, size_t size);
-void knh_free(void *block, size_t size);
+void knh_free(Ctx *ctx, void *block, size_t size);
 void *DBG2_malloc(Ctx *ctx, size_t size);
-void DBG2_free(void *p, size_t size);
+void DBG2_free(Ctx *ctx, void *p, size_t size);
+void *knh_fastmalloc(Ctx *ctx, size_t size);
+void knh_fastfree(Ctx *ctx, void *block, size_t size);
 knh_Object_t *new_PObject__NNctx(Ctx *ctx, knh_flag_t flag, knh_class_t bcid, knh_class_t cid);
 knh_Object_t *new_PObject0(Ctx *ctx, knh_flag_t flag, knh_class_t bcid, knh_class_t cid);
 knh_Object_t *new_ObjectX_malloc(Ctx *ctx, knh_flag_t flag, knh_class_t bcid, knh_class_t cid, size_t size);
 Object *new_Object(Ctx *ctx, knh_flag_t flag, knh_class_t cid);
 void knh_Object_RCsweep(Ctx *ctx, Object *o);
 void knh_Object_free(Ctx *ctx, knh_Object_t *o);
-void knh_Object_traverse(Ctx *ctx, knh_Object_t *o, f_traverse ftr);
+void knh_Object_traverse(Ctx *ctx, knh_Object_t *o, knh_ftraverse ftr);
 Object *new_Nue__T(Ctx *ctx, char *text);
 knh_String_t *new_StringX__T(Ctx *ctx, knh_class_t cid, char *text);
 void KNH_TSTATICOBJ(knh_Object_t **varaddr);
 void knh_tObject_init0(void);
-void knh_tObject_traverse(Ctx *ctx, f_traverse ftr);
+void knh_tObject_traverse(Ctx *ctx, knh_ftraverse ftr);
 /* ../konoha/runtime/knh_tPackage.c */
 void KNH_TDRVAPI(Ctx *ctx, char *alias, knh_drvapi_t* p);
 knh_drvapi_t *knh_System_getDRVAPI(Ctx *ctx, int type, knh_bytes_t name);
 void KNH_TSTATICLIB__T(Ctx *ctx, char *text, void *func);
+METHOD knh__System_hasLibrary(Ctx *ctx, knh_sfp_t *sfp);
 char *knh_format_packagedir(char *buf, size_t bufsiz, char *homedir);
 int knh_System_using(Ctx *ctx, knh_bytes_t name);
 NameSpace *knh_Runtime_getNameSpace(Ctx *ctx, knh_bytes_t name);
@@ -1169,7 +1175,7 @@ ClassSpec *knh_System_loadClassSpec(Ctx *ctx, knh_class_t bcid, knh_bytes_t urn)
 /* ../konoha/runtime/knh_tStruct.c */
 int IS_sid(knh_struct_t sid);
 void knh_tStruct_init0(void);
-void knh_tStruct_traverse(Ctx *ctx, f_traverse f);
+void knh_tStruct_traverse(Ctx *ctx, knh_ftraverse f);
 knh_struct_t KNH_TSTRUCT(Ctx *ctx, 		knh_struct_t sid, size_t size, char *name, 		f_tStruct_init f0, f_tStruct_copy f1, /* f_tStruct_compare f2,*/ f_tStruct_traverse f3, 		f_hashCode f4, f_compareTo f5);
 char *knh_tstruct_name(knh_struct_t sid);
 /* ../konoha/runtime/konoha_api.c */
@@ -1203,6 +1209,7 @@ METHOD knh__Script_addHistory(Ctx *ctx, knh_sfp_t *sfp);
 void knh_Object_lock(Ctx *ctx, Object *o);
 void knh_Object_unlock(Ctx *ctx, Object *o);
 /* ../konoha/runtime/konoha_throwcatch.c */
+void knh_Context__s(Ctx *ctx, Context *o, OutputStream *w, String *m);
 /* ../konoha/runtime/konoha_time.c */
 double knh_gettime();
 /* ../konoha/runtime/konoha_typesystem.c */
