@@ -192,12 +192,12 @@ typedef knh_ushort_t              knh_flag_t;    /* flag field */
 		#define KNH_FLOAT_MAX             DBL_MAX
 		#define KNH_FLOAT_MIN             (-(DBL_MAX))
 		#define KNH_FLOAT_STEP            DBL_MIN
-		#define KNH_FLOAT_FMT             "%lf"
-		#define KNH_FLOAT_FMT1            "%.1lf"
-		#define KNH_FLOAT_FMT2            "%.2lf"
-		#define KNH_FLOAT_FMT3            "%.3lf"
-		#define KNH_FLOAT_FMT4            "%.4lf"
-		#define KNH_FLOAT_FMTE            "%le"
+		#define KNH_FLOAT_FMT             "%f"
+		#define KNH_FLOAT_FMT1            "%.1f"
+		#define KNH_FLOAT_FMT2            "%.2f"
+		#define KNH_FLOAT_FMT3            "%.3f"
+		#define KNH_FLOAT_FMT4            "%.4f"
+		#define KNH_FLOAT_FMTE            "%e"
 	#endif
 #endif
 
@@ -261,6 +261,8 @@ typedef unsigned long long int         knh_uint64_t;
 
 #endif/*KNH_USING_INT64*/
 
+#define _DCAST(t,v)     ((t)v)
+
 /* ------------------------------------------------------------------------ */
 /* String, knh_uchar_t */
 /* ------------------------------------------------------------------------ */
@@ -297,7 +299,8 @@ typedef knh_ushort_t          knh_methodn_t;
 /* Object */
 /* ------------------------------------------------------------------------ */
 
-#define KNH_OBJECT_MAGIC      578
+#define KNH_OBJECT_MAGIC         578
+#define KNH_FASTMALLOC_MAGIC     911
 
 #ifdef KONOHA_WITH_RCGC
 #define KNH_HOBJECT_REFC      1
@@ -351,6 +354,19 @@ typedef struct knh_Object_t {
 /* Context */
 /* ------------------------------------------------------------------------ */
 
+#define ARG_int(a)         ((knh_int_t)(a.i)->value)
+#define ARG_uint(a)        ((knh_uint_t)(a.i)->value)
+#define ARG_integer(a)     ((a.i)->value)
+#define ARG_uinteger(a)    ((knh_uinteger_t)(a.i)->value)
+
+#define ARG_float(a)       ((float)(a.f)->value)
+#define ARG_double(a)      ((double)(a.f)->value)
+#define ARG_char(a)        (knh_String_tochar(a.s))
+#define ARG_bytes(a)       (knh_Bytes_tobytes(a.s))
+#define ARG_cid(a)         ((a.c)->cid)
+#define ARG_Object_cid(a)  knh_Object_cid(a.o)
+#define ARG_cptr(a)        ((a.n)->cptr)
+
 /* ------------------------------------------------------------------------ */
 
 typedef struct knh_sfp_t {
@@ -361,6 +377,7 @@ typedef struct knh_sfp_t {
 		struct knh_Class_t  *c;
 		struct knh_String_t *s;
 		struct knh_Bytes_t  *b;
+		struct knh_COBJ_t   *n;
 		struct knh_Method_t *mtd;
 		struct knh_Exception_t *e;
 		struct knh_ExceptionHandler_t *hdr;
@@ -381,6 +398,7 @@ typedef struct knh_Context_t {
 	knh_sfp_t*                   stack;
 	knh_sfp_t*                   ebp;
 	size_t                       stacksize;
+	char*                        doing;
 	struct knh_String_t*         enc;
 	struct knh_InputStream_t*    in;
 	struct knh_OutputStream_t*   out;
@@ -406,12 +424,12 @@ typedef const knh_Context_t    Ctx;
 #define KNH_TSTRUCT_SIZE 256
 #endif
 
-typedef void (*f_traverse)(Ctx *ctx, Object *);
+typedef void (*knh_ftraverse)(Ctx *ctx, Object *);
 
 typedef void        (*f_tStruct_init)(Ctx *, void *, int, Object *);
 typedef void        (*f_tStruct_copy)(Ctx *, void *, void *);
 typedef int         (*f_tStruct_compare)(void *, void *);
-typedef void        (*f_tStruct_traverse)(Ctx *, void *, f_traverse);
+typedef void        (*f_tStruct_traverse)(Ctx *, void *, knh_ftraverse);
 
 typedef knh_uint_t                knh_hcode_t;  /* knh_hcode_t */
 typedef union {
@@ -512,14 +530,14 @@ typedef struct {
 /* ------------------------------------------------------------------------ */
 
 #ifdef _MSC_VER
-typedef void   (KNH_CC_FASTCALL *f_method)(Ctx *, knh_sfp_t *);
+typedef void   (KNH_CC_FASTCALL *knh_fmethod)(Ctx *, knh_sfp_t *);
 #else
-typedef METHOD (*f_method)(Ctx *, knh_sfp_t *);
+typedef METHOD (*knh_fmethod)(Ctx *, knh_sfp_t *);
 #endif
 
 typedef void       MapData;
 struct knh_Mapper_t;
-typedef Object*    (*f_mapper)(Ctx *, Object *, struct knh_Mapper_t *);
+typedef Object*    (*knh_fmapper)(Ctx *, Object *, struct knh_Mapper_t *);
 
 typedef knh_ushort_t             knh_line_t;
 
@@ -600,13 +618,13 @@ typedef void knh_regex_t;
 typedef struct {
 	int rm_so;   /* start of match */
 	int rm_eo;   /* endo of match */
-	char *rm_name;  /* NULL, if not NAMED */
+	knh_bytes_t rm_name;  /* {NULL, 0}, if not NAMED */
 } knh_regmatch_t;
 
 typedef knh_regex_t* (*knh_fregmalloc)(Ctx *);
 typedef int (*knh_fregcomp)(Ctx *, knh_regex_t *, char *pattern, int flags);
 typedef int (*knh_fregexec)(Ctx *, knh_regex_t *, char *str, size_t nmatch, knh_regmatch_t p[], int flags);
-typedef void (*knh_fregfree)(knh_regex_t *);
+typedef void (*knh_fregfree)(Ctx *, knh_regex_t *);
 
 typedef struct {
 	int  type;
@@ -617,6 +635,29 @@ typedef struct {
 	knh_fregfree   regfree;
 } knh_regex_drvapi_t;
 
+/* ------------------------------------------------------------------------ */
+/* KNH_DRVAPI_TYPE__DB */
+
+typedef void   knh_db_t;
+typedef        knh_db_t* (*knh_fdbopen)(Ctx *ctx, knh_bytes_t url);
+typedef struct knh_ResultSet_t* (*knh_fdbquery)(Ctx *ctx, knh_db_t *, knh_bytes_t query);
+typedef void   (*knh_fdbclose)(Ctx *ctx, knh_db_t *);
+
+struct knh_ResultSet_t;
+typedef void   knh_dbcur_t;
+typedef int    (*knh_fdbcurnext)(Ctx *, knh_dbcur_t *, struct knh_ResultSet_t*);
+typedef void   (*knh_fdbcurfree)(knh_dbcur_t *);
+
+typedef struct {
+	int  type;
+	char *name;
+	knh_fdbopen   dbopen;
+	knh_fdbquery  dbquery;
+	knh_fdbclose  dbclose;
+	knh_fdbcurnext dbcurnext;
+	knh_fdbcurfree dbcurfree;
+} knh_db_drvapi_t;
+
 /* ======================================================================== */
 /* mutex */
 /* ======================================================================== */
