@@ -29,8 +29,11 @@
 
 #include<konoha.h>
 
+#define KNH_PKGNAME "unix"
+
 #ifdef KNH_USING_POSIX
 #include <unistd.h>
+#include <signal.h>
 #endif
 
 
@@ -52,7 +55,6 @@ METHOD knh__System_getpid(Ctx *ctx, knh_sfp_t *sfp)
 	KNH_RETURN_Int(ctx, sfp, getpid());
 }
 
-
 /* ------------------------------------------------------------------------ */
 /* @method[CONST] Int! System.getppid() */
 
@@ -62,6 +64,28 @@ METHOD knh__System_getppid(Ctx *ctx, knh_sfp_t *sfp)
 	KNH_RETURN_Int(ctx, sfp, getppid());
 }
 
+/* ------------------------------------------------------------------------ */
+/* @method[CONST] void System.kill(Int! pid, Int! sig) */
+
+static
+METHOD knh__System_kill(Ctx *ctx, knh_sfp_t *sfp)
+{
+	KNH_SECURE(ctx);
+	KNH_BESTRICT(ctx, kill(ARG_int(sfp[1]), ARG_int(sfp[2])), != -1);
+	KNH_RETURN_void(ctx, sfp);
+}
+
+/* ------------------------------------------------------------------------ */
+/* @method[CONST] void System.system(String! cmd) */
+
+static
+METHOD knh__System_system(Ctx *ctx, knh_sfp_t *sfp)
+{
+	KNH_SECURE(ctx);
+	KNH_BESTRICT(ctx, system(ARG_char(sfp[1])), != -1);
+	KNH_RETURN_void(ctx, sfp);
+}
+
 /* ======================================================================== */
 
 #endif/*KNH_USING_POSIX*/
@@ -69,21 +93,26 @@ METHOD knh__System_getppid(Ctx *ctx, knh_sfp_t *sfp)
 /* ======================================================================== */
 /* [KNHAPI] */
 
-KNHAPI(int) knhunix_init(Ctx *ctx)
+int knhunix_init(Ctx *ctx)
 {
 #ifdef KNH_USING_POSIX
 	KNH_NOTICE(ctx, "loading unix..");
 	konoha_addMethod(ctx, "@Const Int! System.getpid()", knh__System_getpid);
 	konoha_addMethod(ctx, "@Const Int! System.getppid()", knh__System_getppid);
-	return 1;
+	konoha_addMethod(ctx, "@Const void System.kill(Int! pid, Int! sig)", knh__System_kill);
+	konoha_addIntConst(ctx, "SIG_KILL", SIGKILL);
+
+	konoha_addMethod(ctx, "@Const void System.shell(String! cmd)", knh__System_system);
+	konoha_addMethod(ctx, "@Const void System.system(String! cmd)", knh__System_system);
 #else
 	KNH_WARNING(ctx, "unsupported unix package..");
 #endif
+	return 1;
 }
 
 /* ------------------------------------------------------------------------ */
 
-KNHAPI(void) knhunix_traverse(Ctx *ctx, f_traverse ftr)
+void knhunix_traverse(Ctx *ctx, knh_ftraverse ftr)
 {
 	if(konoha_issweep(ftr)) {
 
@@ -92,6 +121,24 @@ KNHAPI(void) knhunix_traverse(Ctx *ctx, f_traverse ftr)
 
 /* ------------------------------------------------------------------------ */
 
+static knh_pkgmeta_t PKGDATA = {
+	KONOHA_BUILDID, /* Don't change this */
+	KNH_PKGNAME,    /* package name (not NULL) */
+	"1.0",  /* package version (not NULL) */
+	NULL,   /* additional information */
+	KONOHA_URLBASE "package.unix", /* URL */
+	knhunix_init,
+	knhunix_traverse,
+	NULL
+};
+
+KNHAPI(knh_pkgmeta_t*) knhunix_load(Ctx *ctx)
+{
+	return &(PKGDATA);
+}
+
+/* ------------------------------------------------------------------------ */
+
 #ifdef __cplusplus
 }
 #endif
